# Change Log

## 1.5.1(2023-05-10)

修复bug:

* 当--bf --fb参数指定时会出现cutoff输出文件不存在的问题

## 1.5.0(2023-04-27)

功能:

* 增加参数 --rank 选择barcode rank算法,目前支持knee 和 inflection,默认inflection; 增加R脚本,环境变量PATH要包含Rscript路径

## 1.4.7(2023-03-31)

功能:

* 支持chromap输出的bam文件,此格式qname带后缀/1 /2

## 1.4.6(2022-12-22)

功能:

* 对bed输入文件,支持30bp的barcode,即最后10bp为tn5,但是可能不做tn5(读取bed时,若tn5序列不在tn5.list中,则打印警报并跳过此行); bam的barcode格式保持不变

## 1.4.5(2022-12-15)

功能:

* 增加参数--fb,默认为0不生效; 当计算bead骤降的rank数超过此阈值,使用此阈值,即限制bead数
* --tn5 参数开放出来,默认为0不生效; 接受一个非负数作为tn5长度
* 计算bead calling和画knee图时去除线粒体数据

## 1.4.4(2022-08-02)

功能:

* 输出全部的细胞的统计到metadata文件中,解决meta中CB与barcodeMerge.tsv不同的问题

## 1.4.3(2022-05-07)

功能:

* 增加参数 --mix-species 以支持用户设置混合样品,此时--mc必须输入两个mito,用逗号分割
* 更新meta统计,加入totalMouseMitoFrag totalHumanMitoFrag uniqMouseMitoFrag uniqHumanMitoFrag

## 1.4.2(2022-04-14)

功能:

* 支持人鼠混合样品的统计

## 1.4.1(2022-03-15)

功能:

* 使用bed文件第五列作为dup个数,以修复饱和度计算异常的问题

## 1.4.0(2022-02-28)

功能:

* 输出bam和fragment文件中保留线粒体数据
* 支持输入文件为.bed格式,程序通过文件后缀名自动判断

## 1.3.8(2021-08-11)

功能:

* 增加标准输出的日志

## 1.3.7(2021-07-04)

功能:

* 解决创建blacklist的线段树时的内存异常问题

## 1.3.6(2020-12-08)

功能:

* 解决当没有--mc 输入时,输出结果文件*.Metadata.tsv 为空的问题

## 1.3.5(2020-11-30)

功能:

* 降低内存消耗,如果内存超过预算,可以使用-c 1 启用单线程模式,但是会降低速度

## 1.3.4(2020-11-04)

功能:

* 添加对bam records进行的PROPER_PAIR的检查

## 1.3.3(2020-10-29)

功能:

* 更新输出的统计结果文件,增加tssProportion列
  
## 1.3.2(2020-10-29)

功能:

* 去除对bam records进行的PROPER_PAIR的检查
* 增加对barcode无后缀runname的支持
  
## 1.3.1(2020-10-21)

功能:

* 将子命令名称由 *count* 改为 *merge*, *reanno* 改为 *transid*
* 删除部分无用的输出文件,修改文件名及文件头信息,并将输出的文件格式统一改为 **tsv**
* 允许用户不输入 *-r* 参数或 *--bg --bl --ts*, 此种情况输出的QC文件信息会有缺失
* 将原参数标识 *--bt* 替换为 *--bt1*,含义不变;并新增输入参数 *--bt2* 指定输出barcode的tag,默认为 **DB**
* 子命令 *transid* 输出的结果bam文件名称添加后缀 *_transid.bam*

## 1.3.0(2020-10-10)

功能:

* 增加子命令 *reanno* 对bam文件进行重新注释,原有计算功能使用子命令 *count*
* 去除 *--br* 参数,基于用户一批数据只有一个 *run name* 的假设
* 将参数 *--bp --jp* 的含义由百分比改成TopN的数值;更新骤降阈值的计算方法;默认使用算法计算骤降阈值,如果提供了 *--bf--ji* 参数,优先使用提供的参数,如果同时还提供了 *--bp --jp*,则选择后者
* 将饱和度计算的输入数据由原始fragments替换为计算cell barcode之后的数据
* 将相似barcode的判断规则由fragments的start或end相同改为 **start与end相同**

## 1.2.0(2020-09-10)

功能:

* 将画图模块由R脚本转换为python脚本,生成可交互的html页面报告
* 画图模块增加饱和度相关输出,只有当用户输入参数 *--sat* 时生效

测试:

* 测试了blacklist文件为空或者为整条染色体长度的情况,程序无异常
* 测试了contig个数达到7k的情况,程序无异常

## 1.1.0(2020-08-21)

功能:

* 参数 *-b* 改为非必需参数,添加默认的1536种barcode list文件
* 当用户没有指定 *--br* 参数时,将遍历整个bam文件查找run name改为只查找一条染色体数据
* 将默认日志输出路径从可执行文件所在目录,变为用户运行脚本的当前路径,并增加 *--logs* 参数,接受用户自定义路径
* 对数据结果文件建立索引 *\*.bai \*.tbi*

问题:

* 修复依赖库问题,无需添加 *lib* 路径到动态链接库,由程序自动查找
* 修复部分数据计算jaccard index异常问题

## 1.0.0(2020-08-13)

初版本,完成基本功能
